@@ -6,7 +6,9 @@
   (d-PushPosition)
   (d-CheckScore)
   (if (not CheckScore::return)
-    (let ((ok (d-GetUserInput "Score Check: Error in this measure" "Try to print anyway?" "n")))
+    (let ((ok #f))
+      (d-InfoDialog (_ "Score Check: Error in this measure"))
+      (set! ok (RadioBoxMenu (cons (_ "Print Anyway") "y") (cons (_ "Cancel") "n")))
 			(if (equal? ok "n")
 				(begin
 					(d-PopPushPosition);;goes to the position on the top of the stack, replacing the top of the stack with the position before it went
