@@ -242,7 +242,7 @@
 										(d-InfoDialog (_"Slur Re-shaped"))
 										(SetSlur vals)
 										(d-SetSaved #f)))))
-				
+(define GetSlurShape::WarningGiven #f)				
 (define (GetSlurShape)
 		(let ()
 			(define (get-control-point n)
@@ -251,7 +251,15 @@
 					((2) (d-InfoDialog (_"Now click second control point of the slur, the next red cross to the right"))(d-GetControlPoint 2))
 					((3) (d-InfoDialog (_"Now click third control point of the slur, the next red cross to the right"))(d-GetControlPoint 3))
 					((4) (d-InfoDialog (_"Now click last control point at the end of the slur, the last red cross to the right"))(d-GetControlPoint 4))))
-			(if (d-Directive-score? "ToggleCurveControl")
+			(if (and (not GetSlurShape::WarningGiven) (not (d-Directive-score? "ToggleCurveControl")))
+        (begin
+          (set! GetSlurShape::WarningGiven #t)
+          (d-WarningDialog (_"To re-shape slurs it is better to have the control points marked.
+Use the right click menu to turn these on before invoking this command.
+However, as this is not working well for multiple staffs, you can do without -
+dismiss this dialog and
+simply guess at suitable points."))))
+      
 					(begin
 						(d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest\n(Positioning will be done with respect to this height)"))
 						(if (d-GetReferencePoint)
@@ -260,9 +268,7 @@
 										(get-control-point 2)
 										(get-control-point 3)
 										(get-control-point 4))
-										(ReshapeSlur)))))
-					(d-WarningDialog (_"To re-shape slurs you need to have the control points marked.
-Use the right click menu to turn these on before invoking this command")))))
+										(ReshapeSlur)))))))
 				
 
 (define RestoreSlurPrompt (cons	(_ "Restore Default Slur Shape/Position")	(_"Removes your customization of this slur")))
@@ -289,6 +295,7 @@ Use the right click menu to turn these on before invoking this command")))))
 			((shape) (GetSlurShape)))))
 			
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+(define EditTarget::WarningGiven #f)
 (define (EditTarget)
 	(let ((target (d-GetTargetInfo)) (target-type #f)(grob #f)(tag #f))	
 	(define ta-tag "TextAnnotation")
@@ -303,18 +310,21 @@ Use the right click menu to turn these on before invoking this command")))))
 							
 	(define (do-center-relative-offset)
 		(let ((offset #f))
-			(if (d-Directive-score? "ToggleWysiwygMarks")
-				(begin
-					(d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest\n(Positioning will be done with respect to this height)"))
-					(d-GetReferencePoint)
-					(d-InfoDialog (_"Now click on the position desired for the object"))
-					(set! offset (d-GetOffset))
-					(if offset
-						(begin
-							(d-InfoDialog (_ "Re-positioned"))
-							(TweakOffset grob tag (number->string (car offset)) (number->string (cdr offset))))))
-				(d-WarningDialog (_"To re-position stuff attached to notes you need to have the locations of the notes marked with red dots.
-Use the right click menu to turn these on before invoking this command")))))
+			(if (and (not EditTarget::WarningGiven) (not (d-Directive-score? "ToggleWysiwygMarks")))
+        (begin
+          (set! EditTarget::WarningGiven #t)
+          (d-WarningDialog (_"To re-position stuff attached to notes accurately you need to have the locations of the objects marked with red dots.
+You can use the right click menu to turn these on before invoking this command. However, since this marking code is only working well for single staffs, you can go ahead without.
+To do this dismiss this dialog and guess at where the red spot is on the object."))))
+
+        (d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest\n(Positioning will be done with respect to this height)"))
+        (d-GetReferencePoint)
+        (d-InfoDialog (_"Now click on the position desired for the object"))
+        (set! offset (d-GetOffset))
+        (if offset
+          (begin
+            (d-InfoDialog (_ "Re-positioned"))
+            (TweakOffset grob tag (number->string (car offset)) (number->string (cdr offset)))))))
 							
 	(define (do-direction)
 		(let ((direction #f)
@@ -427,7 +437,7 @@ Use the right click menu to turn these on before invoking this command")))))
 										(disp "cancelled"))))))))))  ;EditTarget end		
 											
 ;;;; Toggles a postfix annotation on a chord, with editing for direction or offset
-(define (ChordAnnotation tag lilypond params graphic)
+(define* (ChordAnnotation tag lilypond params graphic #:optional display)
 	(define (set-option option)
 					(case (car option)
 							((direction) (cdr option))
@@ -460,7 +470,7 @@ Use the right click menu to turn these on before invoking this command")))))
 									(d-WarningDialog "Cannot complete operation - cursor moved or bad parameter list")))
 							(begin  ;;;no parameters, toggle annotation off/on
 											
-											(ToggleChordDirective tag graphic lilypond DENEMO_OVERRIDE_ABOVE)))))
+											(ToggleChordDirective tag graphic lilypond DENEMO_OVERRIDE_ABOVE display)))))
 											
 											
 																
