@@ -46,6 +46,8 @@ extern "C" {
 
 #define DENEMO_FILE_SUFFIX ".denemo"
 
+#define DENEMO_NO_COMMAND (-1) /* command id for no command */
+
 #define g_malloc(a) g_malloc0(a) /* for extensible debuggable code */
 #if 0
   //use this to detect bad access to G_OBJECT
@@ -64,6 +66,14 @@ extern "C" {
 #define g_string_free
 #endif
 
+#define DEFAULT_COMMANDS "Default.commands"
+#define DEFAULT_KEYBINDINGS "Default.shortcuts"
+#ifdef G_OS_WIN32
+#define PREFS_FILE "denemorcV2"
+#else
+#define PREFS_FILE "denemorc"
+#endif
+  
 #ifdef G_OS_WIN32
 #define mswin g_print
 #else
