@@ -350,6 +350,37 @@ typedef struct DenemoKeymap
 
 }keymap;
 
+/** @struct command_row
+ *  @brief This structure represents commands in the keymap command list.
+ */
+typedef struct command_row
+{
+  KeymapCommandType type;
+  GtkAction *action;
+  gchar *name;
+  gchar *label;
+  gchar *tooltip;
+  gpointer callback;
+  GtkListStore *bindings;
+  gboolean hidden;
+  gboolean deleted;
+} command_row;
+
+//index of columns in the keymap command list store FIXME if you add columns you must add them in keymap_get_command_row and allocate_keymap !!!!
+enum
+{
+  COL_TYPE = 0,
+  COL_ACTION,
+  COL_NAME,
+  COL_LABEL,
+  COL_TOOLTIP,
+  COL_CALLBACK,
+  COL_BINDINGS,
+  COL_HIDDEN,
+  COL_DELETED,
+  N_COLUMNS
+} COMMAND_COLS;
+
 typedef enum { TYPESET_EXCERPT, TYPESET_MOVEMENT, TYPESET_ALL_MOVEMENTS} typeset_type;
 
 /**
@@ -389,6 +420,7 @@ typedef struct DenemoPrefs
   gboolean cursor_highlight; /** Should the cursor be highlighted */
   gboolean return_key_is_special; /** Should the Return key be treated as movable shortcut */
   gboolean newbie; /** Give maximum help */
+  gboolean learning; /** Show which keypresses have been used */
   gboolean progressbardecorations; /** TRUE if you want window decorations on progressbar */
   gboolean toolbar; /**< makes the toolbar visible */
   gboolean playback_controls; /**< makes the playback controls visible */
@@ -427,6 +459,7 @@ typedef struct DenemoPrefs
   GString *portaudio_device;
   unsigned int portaudio_sample_rate;/**< sample rate in Hz > */
   unsigned int portaudio_period_size;/**< The size of the audio buffers (in frames).> */
+  unsigned int maxrecordingtime;/**< The maximum time a recording can be in seconds.> */
 
   // PortMidi options
   GString *portmidi_input_device;
@@ -444,8 +477,6 @@ typedef struct DenemoPrefs
   gint tooltip_browse_timeout;/** < timeout before a tooltip appears in tooltip browse mode */
   gint tooltip_browse_mode_timeout;/** < timeout before a tooltip browse mode is dropped*/
 
-    
-  GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
   GString *username; /**< Username for use on denemo.org website */
   GString *password; /**< password  for use on denemo.org website (blank means prompt for username) */
@@ -915,6 +946,7 @@ typedef struct DenemoGUI
   InputSource last_source;/**< Where the last input came from */
   MidiDestination midi_destination;/**< Where MIDI in should go */
   GQueue *pending_midi;/**< a MIDI effect to be output with the next note */
+  gboolean audio_recording;
   input_mode mode; /**< Input mode for Score */
   GtkWidget *progressbar;
 
