@@ -8,7 +8,7 @@
 
 #include "bookmarks.h"
 #include "moveviewport.h"
-
+#include "utils.h"
 
 
 /**
@@ -41,8 +41,8 @@ addbookmark (GtkAction * action, gpointer param)
   Bookmark *bm = (Bookmark *) g_malloc0 (sizeof (Bookmark));
   bm->bar = si->currentmeasurenum;
   bm->staff = si->currentstaffnum;
-  if(si->bookmarks)
-    bm->id = g_list_length(si->bookmarks);
+  if (si->bookmarks)
+    bm->id = g_list_length (si->bookmarks);
 
   si->bookmarks = g_list_append (si->bookmarks, bm);
 
@@ -56,42 +56,49 @@ deletebookmarks (GtkAction * action, gpointer param)
   DenemoGUI *gui = Denemo.gui;
   GList *g;
   DenemoScore *si = gui->si;
-  for(g=si->bookmarks;g;g=g->next) {
-    g_free(g->data);
-  }
+  for (g = si->bookmarks; g; g = g->next)
+    {
+      g_free (g->data);
+    }
   si->bookmarks = NULL;
 }
+
 void
 nextbookmark (GtkAction * action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
- if(gui->si->bookmarks){
-   GList *g = g_list_nth(gui->si->bookmarks, gui->si->currentbookmark+1);
-   if(g == NULL) {
-     gdk_beep();//wrap around
-     g = gui->si->bookmarks;
-     gui->si->currentbookmark=-1;
-   }
-   Bookmark *bm = g->data;
-   findbookmark (gui, bm->bar, bm->staff);
-   gui->si->currentbookmark++;
- }
+  if (gui->si->bookmarks)
+    {
+      GList *g = g_list_nth (gui->si->bookmarks, gui->si->currentbookmark + 1);
+      if (g == NULL)
+        {
+          gdk_beep ();          //wrap around
+          g = gui->si->bookmarks;
+          gui->si->currentbookmark = -1;
+        }
+      Bookmark *bm = g->data;
+      findbookmark (gui, bm->bar, bm->staff);
+      gui->si->currentbookmark++;
+    }
 }
+
 void
 prevbookmark (GtkAction * action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
- if(gui->si->bookmarks){
-   GList *g = g_list_nth(gui->si->bookmarks, gui->si->currentbookmark-1);
-   if(g == NULL) {
-     gdk_beep();//wrap around
-     g = g_list_last(gui->si->bookmarks);
-     gui->si->currentbookmark=g_list_length(gui->si->bookmarks)+1;
-   }
-   Bookmark *bm = g->data;
-   findbookmark (gui, bm->bar, bm->staff);
-   gui->si->currentbookmark--;
- }
+  if (gui->si->bookmarks)
+    {
+      GList *g = g_list_nth (gui->si->bookmarks, gui->si->currentbookmark - 1);
+      if (g == NULL)
+        {
+          gdk_beep ();          //wrap around
+          g = g_list_last (gui->si->bookmarks);
+          gui->si->currentbookmark = g_list_length (gui->si->bookmarks) + 1;
+        }
+      Bookmark *bm = g->data;
+      findbookmark (gui, bm->bar, bm->staff);
+      gui->si->currentbookmark--;
+    }
 }
 
 /**
@@ -103,38 +110,35 @@ gotobookmark (GtkAction * action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
   g_assert (gui != NULL);
-  if(gui->si->bookmarks==NULL) {
-    warningdialog("No bookmarks are present in this movement");
-    return;
-  }
+  if (gui->si->bookmarks == NULL)
+    {
+      warningdialog ("No bookmarks are present in this movement");
+      return;
+    }
   GtkWidget *dialog;
   GtkWidget *combobox;
-  GList *strings = NULL, *tmp;
-  dialog = gtk_dialog_new_with_buttons (_("Goto Bookmark"),
-					GTK_WINDOW (Denemo.window),
-					(GtkDialogFlags) (GTK_DIALOG_MODAL |
-							  GTK_DIALOG_DESTROY_WITH_PARENT),
-					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-					NULL);
+  dialog = gtk_dialog_new_with_buttons (_("Goto Bookmark"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 
   //g_print ("List length %d\n", g_list_length (gui->si->bookmarks));
 #define FORMAT "%d : Staff %d : Bar %d"
-#if GTK_MAJOR_VERSION==3  
+#if GTK_MAJOR_VERSION==3
+  GList* tmp;
   combobox = gtk_combo_box_text_new ();
   for (tmp = gui->si->bookmarks; tmp; tmp = tmp->next)
     {
       Bookmark *bm = (Bookmark *) tmp->data;
-      char *tmpstring = g_strdup_printf(FORMAT,//FIXME insane use of sscanf see below
-		bm->id, bm->staff, bm->bar);
-      gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT(combobox), tmpstring);
+      char *tmpstring = g_strdup_printf (FORMAT,        //FIXME insane use of sscanf see below
+                                         bm->id, bm->staff, bm->bar);
+      gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), tmpstring);
 #else
+	GList* tmp;
+  GList *strings = NULL;
   combobox = gtk_combo_new ();
   for (tmp = gui->si->bookmarks; tmp; tmp = tmp->next)
     {
       Bookmark *bm = (Bookmark *) tmp->data;
-      char *tmpstring = g_strdup_printf(FORMAT,//FIXME insane use of sscanf see below
-		bm->id, bm->staff, bm->bar);
+      char *tmpstring = g_strdup_printf (FORMAT,        //FIXME insane use of sscanf see below
+                                         bm->id, bm->staff, bm->bar);
 
       strings = g_list_append (strings, tmpstring);
       gtk_combo_set_popdown_strings (GTK_COMBO (combobox), strings);
@@ -145,11 +149,11 @@ gotobookmark (GtkAction * action, gpointer param)
 #endif
     }
 
-  
+
   GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-  GtkWidget *vbox = gtk_vbox_new(FALSE,1);
-  gtk_container_add(GTK_CONTAINER(content_area), vbox);
-  gtk_container_add(GTK_CONTAINER(vbox), combobox);
+  GtkWidget *vbox = gtk_vbox_new (FALSE, 1);
+  gtk_container_add (GTK_CONTAINER (content_area), vbox);
+  gtk_container_add (GTK_CONTAINER (vbox), combobox);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all (dialog);
@@ -158,11 +162,9 @@ gotobookmark (GtkAction * action, gpointer param)
     {
       gint bmid, bms, bmb;
 #if GTK_MAJOR_VERSION==3
-      gchar *tmp =
-	(gchar *)gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combobox));
+      gchar *tmp = (gchar *) gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combobox));
 #else
-      gchar *tmp =
-	(gchar *)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combobox)->entry));
+      gchar *tmp = (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combobox)->entry));
 #endif
       sscanf (tmp, FORMAT, &bmid, &bms, &bmb);
       findbookmark (gui, bmb, bms);
